### 0.10.2 {small}`2023-10-11`

```{rubric} Bugfix
```

* Added compatibility layer for packages relying on `anndata._core.sparse_dataset.SparseDataset`.
  Note that this API is *deprecated* and new code should use {class}`~anndata.experimental.CSRDataset`, {class}`~anndata.experimental.CSCDataset`, and {func}`~anndata.experimental.sparse_dataset` instead.
  {pr}`1185` {user}`ivirshup`
* Handle deprecation warning from `pd.Categorical.map` thrown during `anndata.concat` {pr}`1189` {user}`flying-sheep` {user}`ivirshup`
* Fixed extra steps being included in IO tracebacks {pr}`1193` {user}`flying-sheep`
* `as_dense` argument of `write_h5ad` no longer writes an array without encoding metadata {pr}`1193` {user}`flying-sheep`


```{rubric} Performance
```

* Improved performance of `concat_on_disk` with dense arrays in some cases {pr}`1169` {user}`selmanozleyen`
